@@ -234,6 +234,7 @@ build_article <- function(name,
 
   default_data <- list(
     pagetitle = front$title,
+    toc = toc <- front$toc %||% TRUE,
     opengraph = list(description = front$description %||% pkg$package),
     source = repo_source(pkg, path_rel(input, pkg$src_path)),
     filename = path_file(input),
@@ -363,11 +364,9 @@ data_articles_index <- function(pkg = ".") {
   missing <- !(pkg$vignettes$name %in% listed)
 
   if (any(missing)) {
-    warning(
+    abort(
       "Vignettes missing from index: ",
-      paste(pkg$vignettes$name[missing], collapse = ", "),
-      call. =  FALSE,
-      immediate. = TRUE
+      paste(pkg$vignettes$name[missing], collapse = ", ")
     )
   }
 
@@ -379,12 +378,7 @@ data_articles_index <- function(pkg = ".") {
 
 data_articles_index_section <- function(section, pkg) {
   if (!set_contains(names(section), c("title", "contents"))) {
-    warning(
-      "Section must have components `title`, `contents`",
-      call. = FALSE,
-      immediate. = TRUE
-    )
-    return(NULL)
+    abort("Section must have components `title`, `contents`")
   }
 
   # Match topics against any aliases
@@ -398,7 +392,7 @@ data_articles_index_section <- function(section, pkg) {
   )
 
   list(
-    title = section$title,
+    title = markdown_text_inline(section$title),
     desc = markdown_text_block(section$desc),
     class = section$class,
     contents = purrr::transpose(contents)
@@ -419,6 +413,11 @@ select_vignettes <- function(match_strings, vignettes) {
 default_articles_index <- function(pkg = ".") {
   pkg <- as_pkgdown(pkg)
 
+  if (nrow(pkg$vignettes) == 0L) {
+    return(NULL)
+  }
+
+
   print_yaml(list(
     list(
       title = tr_("All vignettes"),
