@@ -1,3 +1,15 @@
+repo_type <- function(pkg) {
+  home <- repo_home(pkg) %||% ""
+
+  if (grepl("^https?://github\\..+/", home)) {
+    "github"
+  } else if (grepl("^https?://gitlab\\..+/", home)) {
+    "gitlab"
+  } else {
+    "other"
+  }
+}
+
 repo_home <- function(pkg, paths) {
   pkg$repo$url$home
 }
@@ -18,7 +30,7 @@ repo_source <- function(pkg, paths) {
     links <- c(links[1:3], paste0("and ", n - 3, " more"))
   }
 
-  paste0("Source: ", paste(links, collapse = ", "))
+  paste0(tr_("Source:"), " ", paste(links, collapse = ", "))
 }
 
 repo_auto_link <- function(pkg, text) {
@@ -26,12 +38,18 @@ repo_auto_link <- function(pkg, text) {
 
   if (!is.null(url$user)) {
     user_link <- paste0("\\1<a href='", url$user, "\\2'>@\\2</a>")
-    text <- gsub("(\\s|^|\\()@([-\\w]+)", user_link, text, perl = TRUE)
+    text <- gsub("(\\s|[(>])@([-\\w]+)", user_link, text, perl = TRUE)
   }
 
   if (!is.null(url$issue)) {
-    issue_link <- paste0("<a href='", url$issue, "\\1'>#\\1</a>")
-    text <- gsub("#(\\d+)", issue_link, text, perl = TRUE)
+    issue_link <- paste0("<a href='", url$issue, "\\2'>#\\2</a>")
+    text <- gsub("(\\s|[(>])#(\\d+)", paste0("\\1", issue_link), text, perl = TRUE)
+
+    if (!is.null(pkg$repo$jira_projects)) {
+      issue_link <- paste0("<a href='", url$issue, "\\1\\2'>\\1\\2</a>")
+      issue_regex <- paste0("(", paste0(pkg$repo$jira_projects, collapse = "|"),")(-\\d+)")
+      text <- gsub(issue_regex, issue_link, text, perl = TRUE)
+    }
   }
 
   text
@@ -45,13 +63,13 @@ package_repo <- function(desc, meta) {
     return(meta[["repo"]])
   }
 
-  # Otherwise try and guess from BugReports + URLs
+  # Otherwise try and guess from `BugReports` (1st priority) and `URL`s (2nd priority)
   urls <- c(
-    desc$get_field("BugReports", default = character()),
+    sub("/issues/?", "/", desc$get_field("BugReports", default = character())),
     desc$get_urls()
   )
 
-  gh_links <- grep("^https?://git(hub|lab).com/", urls, value = TRUE)
+  gh_links <- grep("^https?://git(hub|lab)\\..+/", urls, value = TRUE)
   if (length(gh_links) > 0) {
     return(repo_meta_gh_like(gh_links[[1]], meta[["repo"]][["branch"]]))
   }
@@ -72,7 +90,7 @@ repo_meta <- function(home = NULL, source = NULL, issue = NULL, user = NULL) {
 
 repo_meta_gh_like <- function(link, branch = NULL) {
   gh <- parse_github_like_url(link)
-  branch <- branch %||% "master"
+  branch <- branch %||% "HEAD"
   repo_meta(
     paste0(gh$host, "/", gh$owner, "/", gh$repo, "/"),
     paste0(gh$host, "/", gh$owner, "/", gh$repo, "/blob/", branch, "/"),
@@ -81,13 +99,13 @@ repo_meta_gh_like <- function(link, branch = NULL) {
   )
 }
 
-# adapted from usethis:::github_link()
 parse_github_like_url <- function(link) {
+  supports_subgroups <- grepl("^https?://gitlab\\.", link)
   rx <- paste0(
     "^",
     "(?<host>https?://[^/]+)/",
     "(?<owner>[^/]+)/",
-    "(?<repo>[^/#]+)"
+    "(?<repo>[^#", "/"[!supports_subgroups], "]+)/"
   )
-  rematch2::re_match(link, rx)
+  re_match(sub("([^/]$)", "\\1/", link), rx)
 }
