@@ -119,22 +119,26 @@ test_that("finds external resources referenced by R code in the article html", {
   )
 })
 
-test_that("BS5 sidebar is removed if TOC is not used", {
+test_that("BS5 article laid out correctly with and without TOC", {
   pkg <- local_pkgdown_site(test_path("assets/articles"), "
     template:
       bootstrap: 5
   ")
 
   expect_output(init_site(pkg))
+  expect_output(toc_true_path <- build_article("standard", pkg))
   expect_output(toc_false_path <- build_article("toc-false", pkg))
-  toc_false_html <- xml2::read_html(toc_false_path)
 
-  # We don't have a main with .col-md-9 if TOC isn't present
-  xpath_contents <- ".//main[contains(@class, 'col-md-9')]"
-  expect_equal(xpath_length(toc_false_html, xpath_contents), 0)
+  toc_true <- xml2::read_html(toc_true_path)
+  toc_false <- xml2::read_html(toc_false_path)
 
-  # The #pkgdown-sidebar is suppressed if the article has toc: false
-  expect_equal(xpath_length(toc_false_html, ".//aside"), 0)
+  # Always has class col-md-9
+  expect_equal(xpath_attr(toc_false, ".//main", "class"), "col-md-9")
+  expect_equal(xpath_attr(toc_true, ".//main", "class"), "col-md-9")
+
+  # The no sidebar without toc
+  expect_equal(xpath_length(toc_true, ".//aside"), 1)
+  expect_equal(xpath_length(toc_false, ".//aside"), 0)
 })
 
 test_that("articles in vignettes/articles/ are unnested into articles/", {
@@ -144,7 +148,10 @@ test_that("articles in vignettes/articles/ are unnested into articles/", {
   pkg <- local_pkgdown_site(test_path("assets/articles"))
   expect_output(path <- build_article("articles/nested", pkg))
 
-  expect_equal(path, file.path(pkg$dst_path, "articles", "nested.html"))
+  expect_equal(
+    normalizePath(path),
+    normalizePath(file.path(pkg$dst_path, "articles", "nested.html"))
+  )
 
   # Check automatic redirect from articles/articles/foo.html -> articles/foo.html
   pkg$meta$url <- "https://example.com"
